@@ -1,5 +1,5 @@
 package Util::Medley::DateTime;
-$Util::Medley::DateTime::VERSION = '0.025';
+$Util::Medley::DateTime::VERSION = '0.026';
 use Modern::Perl;
 use Moose;
 use namespace::autoclean;
@@ -8,6 +8,7 @@ use Time::localtime;
 use Time::Local;
 use Kavorka '-all';
 use Time::ParseDate;
+use Time::HiRes;
 
 use constant SECS_PER_MIN => 60;
 use constant SECS_PER_HOUR => SECS_PER_MIN() * 60;
@@ -19,7 +20,7 @@ Util::Medley::DateTime - Class with various datetime methods.
 
 =head1 VERSION
 
-version 0.025
+version 0.026
 
 =cut
 
@@ -270,4 +271,24 @@ multi method localDateTimeIsValid (Str $dateTime) {
 	return $self->localDateTimeIsValid(dateTime	=> $dateTime);
 }
 
+
+=head2 timeMs
+
+Returns the current epoch in milliseconds.
+
+=over
+
+=item usage:
+
+  $ms = $dt->timeMs;
+  
+=back
+   
+=cut
+
+method timeMs {
+	
+    return int(Time::HiRes::gettimeofday() * 1000);
+}
+
 1;
